==> opencc_plugin-0.0.3.tar.gz: android/src/main/java/com/viptools/opencc/OpenCC.java <==
package com.viptools.opencc;

import android.content.Context;
import android.content.res.AssetManager;
import android.os.Handler;
import android.os.Looper;
import android.util.Log;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

/**
 * Created by zhangqichuan on 29/2/16.
 */
public class OpenCC {

    public static enum OpenCCType {
        HK2S, //hk2s.json Traditional Chinese (Hong Kong Standard) to Simplified Chinese 香港繁體（香港小學學習字詞表標準）到簡體
        S2HK, //s2hk.json Simplified Chinese to Traditional Chinese (Hong Kong Standard) 簡體到香港繁體（香港小學學習字詞表標準）
        S2T, //s2t.json Simplified Chinese to Traditional Chinese 簡體到繁體
        S2TW,//s2tw.json Simplified Chinese to Traditional Chinese (Taiwan Standard) 簡體到臺灣正體
        S2TWP, //s2twp.json Simplified Chinese to Traditional Chinese (Taiwan Standard) with Taiwanese idiom 簡體到繁體（臺灣正體標準）並轉換爲臺灣常用詞彙
        T2HK, //t2hk.json Traditional Chinese to Traditional Chinese (Hong Kong Standard) 繁體到香港繁體（香港小學學習字詞表標準）
        T2S, //t2s.json Traditional Chinese to Simplified Chinese 繁體到簡體
        T2TW,//t2tw.json Traditional Chinese to Traditional Chinese (Taiwan Standard) 繁體臺灣正體
        TW2S, //tw2s.json Traditional Chinese (Taiwan Standard) to Simplified Chinese 臺灣正體到簡體
        TW2SP; //tw2sp.json Traditional Chinese (Taiwan Standard) to Simplified Chinese with Mainland Chinese idiom 繁體（臺灣正體標準）到簡體並轉換爲中國大陸常用詞彙

        public String getValue() {
            if (this == HK2S) {
                return "hk2s.json";
            } else if (this == S2HK) {
                return "s2hk.json";
            } else if (this == S2T) {
                return "s2t.json";
            } else if (this == S2TW) {
                return "s2tw.json";
            } else if (this == S2TWP) {
                return "s2twp.json";
            } else if (this == T2HK) {
                return "t2hk.json";
            } else if (this == T2S) {
                return "t2s.json";
            } else if (this == T2TW) {
                return "t2tw.json";
            } else if (this == TW2S) {
                return "tw2s.json";
            } else if (this == TW2SP) {
                return "tw2sp.json";
            }
            return "s2t.json";
        }
    }


    private static boolean inited = false;

    private static String dataFolder;

    /***
     * @param text           the text to be converted to
     * @param ccType the conversion type
     * @return the converted text
     */
    public static String convert(String text, OpenCCType ccType) {
        if(!inited){
            return text;
        } else {
            return convert(text, ccType.getValue(), dataFolder);
        }
    }

    /***
     * Clear the dictionary data folder, only call this method when update the dictionary data.
     * @param context
     */
    public static void clearDictDataFolder(Context context){
        File dataFolder = new File(context.getFilesDir() + "/openccdata");
        deleteRecursive(dataFolder);
    }

    private static void deleteRecursive(File fileOrDirectory) {
        if (fileOrDirectory.isDirectory())
            for (File child : fileOrDirectory.listFiles())
                deleteRecursive(child);

        fileOrDirectory.delete();
    }

    private static native String convert(String text, String configFile, String absoluteDataFolderPath);

    public static void initialize(Context context, Runnable callback) {
        if(!inited){
            dataFolder = new File(context.getFilesDir() + "/openccdata").getAbsolutePath();

            new Thread(){
                @Override
                public void run() {
                    super.run();

                    System.loadLibrary("OpenCC");

                    copyFolder("openccdata", context, callback);
                }
            }.start();
        }
    }

    private static void copyFolder(String folderName, Context context, Runnable callback) {
        File lastDataFile = new File(context.getFilesDir() + "/openccdata/zFinished2");
        if (!lastDataFile.exists()) {
            File fileFolderOnDisk = new File(context.getFilesDir() + "/" + folderName);
            AssetManager assetManager = context.getAssets();
            String[] files = null;
            try {
                files = assetManager.list(folderName);
            } catch (IOException e) {
                Log.e("tag", "Failed to get asset file list.", e);
            }
            if (files != null) {
                for (String filename : files) {
                    InputStream in = null;
                    OutputStream out = null;
                    try {
                        in = assetManager.open(folderName + "/" + filename);
                        if (!fileFolderOnDisk.exists()) {
                            fileFolderOnDisk.mkdirs();
                        }
                        File outFile = new File(fileFolderOnDisk.getAbsolutePath(), filename);
                        if (!outFile.exists()) {
                            outFile.createNewFile();
                        }
                        out = new FileOutputStream(outFile);
                        copyFile(in, out);
                    } catch (IOException e) {
                        Log.e("tag", "Failed to copy asset file: " + filename, e);
                    } finally {
                        if (in != null) {
                            try {
                                in.close();
                            } catch (IOException e) {
                                // NOOP
                            }
                        }
                        if (out != null) {
                            try {
                                out.close();
                            } catch (IOException e) {
                                // NOOP
                            }
                        }
                    }
                }
            }
        }

        inited = true;

        if(callback != null) {
            new Handler(Looper.getMainLooper()).post(callback);
        }
    }


    private static void copyFile(InputStream in, OutputStream out) throws IOException {
        byte[] buffer = new byte[1024 * 64];
        int read;
        while ((read = in.read(buffer)) != -1) {
            out.write(buffer, 0, read);
        }
    }
}

==> opencc_plugin-0.0.6.tar.gz: android/src/main/java/com/viptools/opencc/OpenCC.java <==
package com.viptools.opencc;

import android.content.Context;
import android.content.res.AssetManager;
import android.os.Handler;
import android.os.Looper;
import android.util.Log;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

/**
 * Created by zhangqichuan on 29/2/16.
 */
public class OpenCC {

    public static enum OpenCCType {
        HK2S, //hk2s.json Traditional Chinese (Hong Kong Standard) to Simplified Chinese 香港繁體（香港小學學習字詞表標準）到簡體
        S2HK, //s2hk.json Simplified Chinese to Traditional Chinese (Hong Kong Standard) 簡體到香港繁體（香港小學學習字詞表標準）
        S2T, //s2t.json Simplified Chinese to Traditional Chinese 簡體到繁體
        S2TW,//s2tw.json Simplified Chinese to Traditional Chinese (Taiwan Standard) 簡體到臺灣正體
        S2TWP, //s2twp.json Simplified Chinese to Traditional Chinese (Taiwan Standard) with Taiwanese idiom 簡體到繁體（臺灣正體標準）並轉換爲臺灣常用詞彙
        T2HK, //t2hk.json Traditional Chinese to Traditional Chinese (Hong Kong Standard) 繁體到香港繁體（香港小學學習字詞表標準）
        T2S, //t2s.json Traditional Chinese to Simplified Chinese 繁體到簡體
        T2TW,//t2tw.json Traditional Chinese to Traditional Chinese (Taiwan Standard) 繁體臺灣正體
        TW2S, //tw2s.json Traditional Chinese (Taiwan Standard) to Simplified Chinese 臺灣正體到簡體
        TW2SP; //tw2sp.json Traditional Chinese (Taiwan Standard) to Simplified Chinese with Mainland Chinese idiom 繁體（臺灣正體標準）到簡體並轉換爲中國大陸常用詞彙

        public String getValue() {
            if (this == HK2S) {
                return "hk2s.json";
            } else if (this == S2HK) {
                return "s2hk.json";
            } else if (this == S2T) {
                return "s2t.json";
            } else if (this == S2TW) {
                return "s2tw.json";
            } else if (this == S2TWP) {
                return "s2twp.json";
            } else if (this == T2HK) {
                return "t2hk.json";
            } else if (this == T2S) {
                return "t2s.json";
            } else if (this == T2TW) {
                return "t2tw.json";
            } else if (this == TW2S) {
                return "tw2s.json";
            } else if (this == TW2SP) {
                return "tw2sp.json";
            }
            return "s2t.json";
        }
    }


    private static boolean inited = false;

    private static String dataFolder;

    /***
     * @param text           the text to be converted to
     * @param ccType the conversion type
     * @return the converted text
     */
    public static String convert(String text, OpenCCType ccType) {
        if(!inited){
            return text;
        } else {
            return convert(text, ccType.getValue(), dataFolder);
        }
    }

    /***
     * Clear the dictionary data folder, only call this method when update the dictionary data.
     * @param context
     */
    public static void clearDictDataFolder(Context context){
        File dataFolder = new File(context.getFilesDir() + "/openccdata");
        deleteRecursive(dataFolder);
    }

    private static void deleteRecursive(File fileOrDirectory) {
        if (fileOrDirectory.isDirectory())
            for (File child : fileOrDirectory.listFiles())
                deleteRecursive(child);

        fileOrDirectory.delete();
    }

    private static native String convert(String text, String configFile, String absoluteDataFolderPath);

    public static void initialize(fnial Context context, fnial Runnable callback) {
        if(!inited){
            dataFolder = new File(context.getFilesDir() + "/openccdata").getAbsolutePath();

            new Thread(){
                @Override
                public void run() {
                    super.run();

                    System.loadLibrary("OpenCC");

                    copyFolder("openccdata", context, callback);
                }
            }.start();
        }
    }

    private static void copyFolder(String folderName, Context context, Runnable callback) {
        File lastDataFile = new File(context.getFilesDir() + "/openccdata/zFinished2");
        if (!lastDataFile.exists()) {
            File fileFolderOnDisk = new File(context.getFilesDir() + "/" + folderName);
            AssetManager assetManager = context.getAssets();
            String[] files = null;
            try {
                files = assetManager.list(folderName);
            } catch (IOException e) {
                Log.e("tag", "Failed to get asset file list.", e);
            }
            if (files != null) {
                for (String filename : files) {
                    InputStream in = null;
                    OutputStream out = null;
                    try {
                        in = assetManager.open(folderName + "/" + filename);
                        if (!fileFolderOnDisk.exists()) {
                            fileFolderOnDisk.mkdirs();
                        }
                        File outFile = new File(fileFolderOnDisk.getAbsolutePath(), filename);
                        if (!outFile.exists()) {
                            outFile.createNewFile();
                        }
                        out = new FileOutputStream(outFile);
                        copyFile(in, out);
                    } catch (IOException e) {
                        Log.e("tag", "Failed to copy asset file: " + filename, e);
                    } finally {
                        if (in != null) {
                            try {
                                in.close();
                            } catch (IOException e) {
                                // NOOP
                            }
                        }
                        if (out != null) {
                            try {
                                out.close();
                            } catch (IOException e) {
                                // NOOP
                            }
                        }
                    }
                }
            }
        }

        inited = true;

        if(callback != null) {
            new Handler(Looper.getMainLooper()).post(callback);
        }
    }


    private static void copyFile(InputStream in, OutputStream out) throws IOException {
        byte[] buffer = new byte[1024 * 64];
        int read;
        while ((read = in.read(buffer)) != -1) {
            out.write(buffer, 0, read);
        }
    }
}
